==> haskell-casa-client-0.0.1-48-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-casa-client.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 casa-client
version:              0.0.1
visibility:           public
id:                   casa-client-0.0.1-7OqP553r64DHxOJaVVR3NT
key:                  casa-client-0.0.1-7OqP553r64DHxOJaVVR3NT
license:              BSD-3-Clause
copyright:            2018-2019 FP Complete
maintainer:           chrisdone@fpcomplete.com
author:               Chris Done
synopsis:             Client for Casa
description:          Client for Casa <https://casa.fpcomplete.com/>
category:             Development
abi:                  37a135d147956092cd4a495feb9db7eb
exposed:              True
exposed-modules:      Casa.Client
hidden-modules:       Paths_casa_client
import-dirs:          /usr/lib/ghc-8.10.1/site-local/casa-client-0.0.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/casa-client-0.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/casa-client-0.0.1
hs-libraries:         HScasa-client-0.0.1-7OqP553r64DHxOJaVVR3NT
depends:
    aeson-1.5.1.0-9flD70y9OJL8EnSIjIcu4t
    attoparsec-0.13.2.4-75xefPYAxam1Yt9FZGmunF base-4.14.0.0
    base16-bytestring-0.1.1.6-DS9xLNC5hoWBUNdBXU0AGB
    bytestring-0.10.10.0 casa-types-0.0.1-5wvLmZOGrgS2UA2YbwGXv3
    conduit-1.3.2-6ZG6T5I5cKQFFD9qyOIpu
    conduit-extra-1.3.5-EeNOQtdUW6E7bNOkpWlcKM
    cryptonite-0.26-JIZdcaiOiQ0E7oAZnbqxMe exceptions-0.10.4
    http-conduit-2.3.7.3-9vdwb3fJwMNHg3c3AaWDDF
    http-types-0.12.3-4xQpZ1dm4sVLlP974qcom6
    memory-0.15.0-EuehB4FMe9b5ts9dSjTFQ5
    network-uri-2.6.3.0-GDqs2hA11G76kDe7SwMard
    resourcet-1.2.4.1-BfFxYNA42v4HhhW9DWi0Jk template-haskell-2.16.0.0
    text-1.2.3.2 th-lift-0.8.1-BllvzgsbE8XFqTlJuRRkNs
    unliftio-core-0.2.0.1-DFzZctvkeWF1j2hnkeOBtq
    unordered-containers-0.2.10.0-BkkEehzCtfP8BROI0EUhVc

haddock-interfaces:   /usr/share/doc/haskell-casa-client/html/casa-client.haddock
haddock-html:         /usr/share/doc/haskell-casa-client/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-casa-client-0.0.1-55-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-casa-client.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 casa-client
version:              0.0.1
visibility:           public
id:                   casa-client-0.0.1-3qyEecbT8jH5lHAovcfTye
key:                  casa-client-0.0.1-3qyEecbT8jH5lHAovcfTye
license:              BSD-3-Clause
copyright:            2018-2019 FP Complete
maintainer:           chrisdone@fpcomplete.com
author:               Chris Done
synopsis:             Client for Casa
description:          Client for Casa <https://casa.fpcomplete.com/>
category:             Development
abi:                  02c4155861f370c015a3a93599e4b3bb
exposed:              True
exposed-modules:      Casa.Client
hidden-modules:       Paths_casa_client
import-dirs:          /usr/lib/ghc-8.10.1/site-local/casa-client-0.0.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/casa-client-0.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/casa-client-0.0.1
hs-libraries:         HScasa-client-0.0.1-3qyEecbT8jH5lHAovcfTye
depends:
    aeson-1.5.2.0-9RTw8ryGp7WIZEOMbLe2St
    attoparsec-0.13.2.4-75xefPYAxam1Yt9FZGmunF base-4.14.0.0
    base16-bytestring-0.1.1.7-IF3oDT09hOj5uLqgHsC3Xr
    bytestring-0.10.10.0 casa-types-0.0.1-5cEvaZYj6D9HwKAZ5jYcbR
    conduit-1.3.2-E73kZTPRwvcC4v4QmnYBd3
    conduit-extra-1.3.5-JbSefpLFWUqKgP8sdbsBOO
    cryptonite-0.26-JIZdcaiOiQ0E7oAZnbqxMe exceptions-0.10.4
    http-conduit-2.3.7.3-ANDcBoCVpuADBCSha3DcIu
    http-types-0.12.3-53LE6EPnjaYL88m7GHuG2H
    memory-0.15.0-EuehB4FMe9b5ts9dSjTFQ5
    network-uri-2.6.3.0-CWpK8ej5SnOAz8dByfK7af
    resourcet-1.2.4.1-BfFxYNA42v4HhhW9DWi0Jk template-haskell-2.16.0.0
    text-1.2.3.2 th-lift-0.8.1-BllvzgsbE8XFqTlJuRRkNs
    unliftio-core-0.2.0.1-DFzZctvkeWF1j2hnkeOBtq
    unordered-containers-0.2.11.0-Gy9Rkzl4w678AYU9aLwMbs

haddock-interfaces:   /usr/share/doc/haskell-casa-client/html/casa-client.haddock
haddock-html:         /usr/share/doc/haskell-casa-client/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
